Public Class Rsspecan_Marker_Functions_Example

    Dim m_Instrument As rsspecan = Nothing

    Private Sub ExitButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ExitButton.Click
        Close()
    End Sub

    Private Sub Rsspecan_Marker_Functions_Example_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Input.SelectedIndex = 0
        PeakType.SelectedIndex = 0

    End Sub

    Private Sub StopButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles StopButton.Click

        PeakType.SelectedIndex = 0
        EnableButtons(False)

    End Sub

    Private Sub EnableButtons(ByVal enable As Boolean)

        PeakType.Enabled = enable
        PeakExcursion.Enabled = enable
        SearchButton.Enabled = enable
        StopButton.Enabled = enable
        StartButton.Enabled = Not enable

    End Sub

    Private Sub SearchButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles SearchButton.Click

        Dim markerPosition, markerAmplitude As Double

        Try
            ' set peak excursion value
            m_Instrument.ConfigureMarkerSearchPeakExcursion(1, Convert.ToDouble(PeakExcursion.Value))

            ' specifies the type of marker search and performs the search
            m_Instrument.MarkerSearch(1, 1, PeakType.SelectedIndex + 1)

            ' returns the position of the selected marker
            m_Instrument.QueryMarker(1, 1, markerPosition, markerAmplitude)

            ' write marker position to panel
            MarkerPositionTxtBox.Text = markerPosition.ToString("E3")
            MarkerAmplitudeTxtBox.Text = markerAmplitude.ToString("F")


        Catch ex As System.Runtime.InteropServices.ExternalException

            Dim message As String

            message = "Instrument Status Error: " + ex.Message + Environment.NewLine
            message += "Instrument Error Code: " + ex.ErrorCode.ToString("X")
            MessageBox.Show(message)

            EnableButtons(False)
            PeakType.SelectedIndex = 0

        End Try
    End Sub

    Private Sub StartButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles StartButton.Click

        Dim timeout As Integer = 15000    ' default value
        Dim markerPosition, markerAmplitude As Double
        Dim instrModel As String

        Try
            UseWaitCursor = True
            System.Windows.Forms.Cursor.Current = Cursors.WaitCursor

            ' initialize driver
            If m_Instrument Is Nothing Then
                m_Instrument = New rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked)
            ElseIf ResetDevice.Checked Then
                m_Instrument.reset()
            End If

            ' Set instrument to single sweep mode - continous mode is done
            ' programmatically because this is the only way how to
            ' synchronize measurement using *OPC

            m_Instrument.ConfigureSignalStatisticSweep(False)

            instrModel = m_Instrument.GetString(rsspecanProperties.RsAttrInstrumentModel)

            If instrModel <> "FSC" And instrModel <> "FSH" Then
                ' select input
                m_Instrument.ServiceConfigureInput(1, Input.SelectedIndex, Convert.ToDouble(GenAmplitude.Value))
            End If

            ' Enable marker
            m_Instrument.SetBoolean(rsspecanProperties.MarkerEnabled, "Win0,M1", True)

            ' perform sweep
            m_Instrument.Initiate(1, timeout)

            ' specifies the type of marker search and performs the search
            m_Instrument.MarkerSearch(1, 1, PeakType.SelectedIndex + 1)

            'returns the position of the selected marker
            m_Instrument.QueryMarker(1, 1, markerPosition, markerAmplitude)

            ' write marker position to panel
            MarkerPositionTxtBox.Text = markerPosition.ToString("E3")
            MarkerAmplitudeTxtBox.Text = markerAmplitude.ToString("F")

            EnableButtons(True)

        Catch ex As System.Runtime.InteropServices.ExternalException

            Dim message As String

            message = "Instrument Status Error: " + ex.Message + Environment.NewLine
            message += "Instrument Error Code: " + ex.ErrorCode.ToString("X")
            MessageBox.Show(message)

            EnableButtons(False)
            PeakType.SelectedIndex = 0

        Finally

            System.Windows.Forms.Cursor.Current = Cursors.Default
            UseWaitCursor = False

        End Try

    End Sub
End Class
